#
# Please do not update/rebuild/touch this package before asking first
# to the KDE Team
# This package is part of the KDE Stack.
#

%bcond_without qt5

%define rel 1

Name:           ksanecore
Version: 24.08.0
Release:        %mkrel %rel
Summary:        Library that provides a Qt interface for the SANE library for scanner hardware
Group:          Graphical desktop/KDE
License:        GPLv2
Url:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz

BuildRequires:  kf6-rpm-macros

BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)

BuildRequires:  cmake(KF6I18n)

%if %{with qt5}
BuildRequires:  kf5-rpm-macros

BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)

BuildRequires:  cmake(KF5I18n)
%endif
BuildRequires:  pkgconfig(sane-backends)

%description
KSaneCore is a library that provides a Qt interface for the
SANE library for scanner hardware.

%files -f %name.lang

#------------------------------------------------------------------------------

%define ksanecore_major 1
%define libksanecore %mklibname ksanecore6_ %ksanecore_major

%package -n     %{libksanecore}
Summary:        %name library
Group:          System/Libraries
Provides:       ksanecore = %version-%release
Requires:       %name >= %version

%description -n %{libksanecore}
KSaneCore is a library that provides a Qt interface for the
SANE library for scanner hardware.

%files -n %{libksanecore}
%_kf6_libdir/libKSaneCore6.so.%{ksanecore_major}{,.*}
%_kf6_libdir/libKSaneCore6.so.%{version}

#------------------------------------------------------------------------------

%define libksanecore_devel %mklibname ksanecore6 -d

%package -n     %{libksanecore_devel}
Summary:        Devel stuff for %name
Group:          Development/KDE and Qt
Requires:       %libksanecore = %version-%release
Provides:       %name-devel = %version-%release

%description -n %{libksanecore_devel}
KSaneCore is a library that provides a Qt interface for the
SANE library for scanner hardware.

This package contains header files needed if you wish to build applications
based on %name.

%files -n %{libksanecore_devel}
%_includedir/KSaneCore6/
%_kf6_libdir/libKSaneCore6.so
%_kf6_libdir/cmake/KSaneCore6/

#------------------------------------------------------------------------------
%if %{with qt5}

%define ksanecore5_major 1
%define libksanecore5 %mklibname ksanecore %ksanecore5_major

%package -n     %{libksanecore5}
Summary:        %name library
Group:          System/Libraries
Provides:       ksanecore-qt5 = %version-%release
Requires:       %name >= %version

%description -n %{libksanecore5}
KSaneCore is a library that provides a Qt interface for the
SANE library for scanner hardware.

%files -n %{libksanecore5}
%_kf5_libdir/libKSaneCore.so.%{ksanecore5_major}{,.*}
%_kf5_libdir/libKSaneCore.so.%{version}

#------------------------------------------------------------------------------

%define libksanecore5_devel %mklibname ksanecore -d

%package -n     %{libksanecore5_devel}
Summary:        Devel stuff for %name (Qt5)
Group:          Development/KDE and Qt
Requires:       %libksanecore5 = %version-%release
Provides:       kf5-%name-devel = %version-%release

%description -n %{libksanecore5_devel}
KSaneCore is a library that provides a Qt5 interface for the
SANE library for scanner hardware.

This package contains header files needed if you wish to build applications
based on %name (Qt5).

%files -n %{libksanecore5_devel}
%_includedir/KSaneCore/
%_kf5_libdir/cmake/KSaneCore/
%_kf5_libdir/libKSaneCore.so
%endif

#------------------------------------------------------------------------------

%prep
%autosetup -p1

%build
%if %{with qt5}
mkdir %{name}_qt5 && pushd %{name}_qt5
%cmake_kf5 -DBUILD_WITH_QT6:BOOL=OFF -S ..
%cmake_build
popd
%endif

%cmake_kf6 -DBUILD_WITH_QT6:BOOL=ON
%cmake_build

%install
%if %{with qt5}
pushd %{name}_qt5
%cmake_install
popd
%endif

%cmake_install

%find_lang %{name} --with-kde --with-html


%changelog
* Thu Aug 22 2024 daviddavid <daviddavid> 24.08.0-1.mga10
+ Revision: 2087671
- New version 24.08.0

* Sat Aug 10 2024 daviddavid <daviddavid> 24.07.90-1.mga10
+ Revision: 2085167
- New version 24.07.90

* Fri Jun 14 2024 daviddavid <daviddavid> 24.05.1-1.mga10
+ Revision: 2073099
- New version 24.05.1

* Wed Jun 05 2024 neoclust <neoclust> 24.05.0-1.mga10
+ Revision: 2069934
- New version 24.05.0

* Thu Apr 18 2024 neoclust <neoclust> 24.02.2-1.mga10
+ Revision: 2058681
- New version 24.02.2

* Wed Feb 28 2024 neoclust <neoclust> 24.02.0-1.mga10
+ Revision: 2045220
- New version 24.02.0

* Tue Feb 06 2024 neoclust <neoclust> 24.01.95-1.mga10
+ Revision: 2037718
- New version 24.01.95

* Sun Feb 04 2024 daviddavid <daviddavid> 24.01.90-2.mga10
+ Revision: 2037130
- enable also the Qt5 support needed for tellico

* Tue Jan 23 2024 neoclust <neoclust> 24.01.90-1.mga10
+ Revision: 2033841
- New version 24.01.90

* Wed Jan 03 2024 neoclust <neoclust> 24.01.85-1.mga10
+ Revision: 2026430
- New version 24.01.85

* Wed Nov 15 2023 daviddavid <daviddavid> 24.01.75-1.mga10
+ Revision: 2007029
- New version 24.01.75
- switch to Qt6/KF6

* Sat Sep 23 2023 neoclust <neoclust> 23.08.1-1.mga10
+ Revision: 1989662
- New version 23.08.1

* Fri May 26 2023 neoclust <neoclust> 23.04.1-1.mga9
+ Revision: 1958337
- New version 23.04.1

* Thu Mar 02 2023 neoclust <neoclust> 22.12.3-1.mga9
+ Revision: 1946551
- New version 22.12.3

* Tue Feb 14 2023 neoclust <neoclust> 22.12.2-1.mga9
+ Revision: 1941844
- New version 22.12.2

* Thu Dec 15 2022 neoclust <neoclust> 22.12.0-1.mga9
+ Revision: 1922965
- New version 22.12.0

* Sat Nov 26 2022 neoclust <neoclust> 22.11.90-1.mga9
+ Revision: 1911460
- New version 22.11.90

* Thu Nov 10 2022 neoclust <neoclust> 22.08.3-1.mga9
+ Revision: 1905311
- New version 22.08.3
- New version 22.08.1

* Tue Aug 30 2022 neoclust <neoclust> 22.08.0-1.mga9
+ Revision: 1882371
- imported package ksanecore

